===============================
shpinfo
===============================

.. image:: https://img.shields.io/travis/yaph/shpinfo.svg
        :target: https://travis-ci.org/yaph/shpinfo

.. image:: https://img.shields.io/pypi/v/shpinfo.svg
        :target: https://pypi.python.org/pypi/shpinfo


A command line program to print meta information about the given shapefile.

* Free software: MIT license
* Documentation: https://pythonhosted.org/shpinfo/.

Usage
-----

.. code:: Bash

    shpinfo myfile.shp
